@@ -2,11 +2,11 @@
 
 __author__ = """Dylan Wootton"""
 __email__ = 'dwootton@mit.edu'
-__version__ = '0.1.20'
+__version__ = '0.1.21'
 
-from .relational.joint_plot import *
+from relational.joint_plot import *
 from .pair_plot import *
 from .distributional import *
-from .relational.relational import *
+from relational.relational import *
 from .data_table import *
 from .interactions import *
\ No newline at end of file
