@@ -1,5 +1,4 @@
-import sys
-sys.path.insert(0, '/Users/dylanwootton/Documents/GitHub/altair/altair')
+
 import altair as alt
 import pandas as pd
 import numpy as np
